from .core import dskit
from .io import load, read_folder, save
from .cleaning import fix_dtypes, rename_columns_auto, replace_specials, missing_summary, fill_missing, outlier_summary, remove_outliers, simple_nlp_clean
from .visualization import plot_missingness, plot_histograms, plot_boxplots, plot_correlation_heatmap, plot_pairplot
from .preprocessing import auto_encode, auto_scale, train_test_auto
from .modeling import QuickModel, compare_models, auto_hpo, evaluate_model, error_analysis
from .explainability import explain_shap
from .eda import basic_stats, quick_eda
from .feature_engineering import *
from .nlp_utils import *
from .advanced_visualization import *
from .advanced_modeling import *
from .auto_ml import *
from .comprehensive_eda import *

# Advanced non-visualization utilities
from .advanced_preprocessing import *
from .time_series_utils import *
from .model_validation import *
from .data_auditing import *
from .database_utils import *
from .model_deployment import *

# Hyperplane utilities
from .hyperplane import *

__version__ = "1.0.4"
